@@ -18,6 +18,7 @@ package manifest
 
 import (
 	"fmt"
+	"path"
 
 	apimachinery "k8s.io/apimachinery/pkg/runtime/schema"
 
@@ -46,7 +47,7 @@ var transformableAllowlist = map[apimachinery.GroupKind]bool{
 type FieldVisitor interface {
 	// Visit is called for each transformable key contained in the object and may apply transformations/aggregations on it.
 	// It should return true to allow recursive traversal or false when the entry was transformed.
-	Visit(object map[string]interface{}, key string, value interface{}) bool
+	Visit(path string, object map[string]interface{}, key string, value interface{}) bool
 }
 
 // Visit recursively visits all transformable object fields within the manifests and lets the visitor apply transformations/aggregations on them.
@@ -81,7 +82,7 @@ func traverseManifestFields(manifest map[string]interface{}, visitor FieldVisito
 	if shouldTransformManifest(manifest) {
 		visitor = &recursiveVisitorDecorator{visitor}
 	}
-	visitFields(manifest, visitor)
+	visitFields("/", manifest, visitor)
 }
 
 func shouldTransformManifest(manifest map[string]interface{}) bool {
@@ -123,23 +124,29 @@ type recursiveVisitorDecorator struct {
 	delegate FieldVisitor
 }
 
-func (d *recursiveVisitorDecorator) Visit(o map[string]interface{}, k string, v interface{}) bool {
-	if d.delegate.Visit(o, k, v) {
-		visitFields(v, d)
+func (d *recursiveVisitorDecorator) Visit(path string, o map[string]interface{}, k string, v interface{}) bool {
+	if d.delegate.Visit(path, o, k, v) {
+		visitFields(path, v, d)
 	}
 	return false
 }
 
 // visitFields traverses all fields and calls the visitor for each.
-func visitFields(o interface{}, visitor FieldVisitor) {
+// navpath: a '/' delimited path representing the fields navigated to this point
+func visitFields(navpath string, o interface{}, visitor FieldVisitor) {
 	switch entries := o.(type) {
 	case []interface{}:
 		for _, v := range entries {
-			visitFields(v, visitor)
+			// this case covers lists so we don't update the navpath
+			visitFields(navpath, v, visitor)
 		}
 	case map[string]interface{}:
 		for k, v := range entries {
-			visitor.Visit(entries, k, v)
+			// TODO(6416) temporary fix for StatefulSet + PVC use case, need to do something similar to the proposal in #6236 for full fix
+			if navpath == "/spec/volumeClaimTemplates" {
+				continue
+			}
+			visitor.Visit(path.Join(navpath, k), entries, k, v)
 		}
 	}
 }
